==> nextcloud-app-contacts-3.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/fi.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Yhteystiedot",
    "All contacts" : "Kaikki yhteystiedot",
    "Details" : "Tiedot",
    "A contacts app for Nextcloud" : "Yhteystietosovellus Nextcloudille",
    "Add new property" : "Lisää uusi ominaisuus",
    "Choose property type" : "Valitse ominaisuuden tyyppi",
    "Add a new picture" : "Lisää uusi kuva",
    "Upload a new picture" : "Lähetä uusi kuva",
    "Choose from files" : "Valitse tiedostoista",
    "Delete picture" : "Poista kuva",
    "Download picture" : "Lataa kuva",
    "Image is too big (max 1MB)." : "Kuva on liian suuri (enintään 1 Mt).",
    "Pick an avatar" : "Valitse avatar",
    "Error while processing the picture." : "Virhe kuvan käsittelyn aikana.",
    "No contact selected" : "Yhteystietoa ei ole valittu",
    "Select a contact on the list to begin" : "Valitse yhteystieto luettelosta aloittaaksesi",
    "Loading" : "Ladataan",
    "Name" : "Nimi",
    "Company" : "Yritys",
    "Title" : "Nimeke",
    "Download" : "Lataa",
    "Generate QR Code" : "Luo QR-koodi",
    "Delete" : "Poista",
    "This contact is not yet synced. Edit it to save it to the server." : "Tätä yhteystietoa ei ole vielä synkronoitu. Muokkaa yhteystietoa tallentaaksesi sen palvelimelle.",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tämä yhteystieto on \"vain luku\"-tilassa. Sinulla ei ole oikeuksia muokata tätä yhteystietoa.",
    "Addressbook" : "Osoitekirja",
    "Groups" : "Ryhmät",
    "New contact" : "Uusi yhteystieto",
    "Deleting the contact in {countdown} seconds" : "Poistetaan yhteystieto {countdown} sekunnin kuluttua",
    "No errors" : "Ei virheitä",
    "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} virheellinen yhteystieto","{failedCount} virheellistä yhteystietoa"],
    "Select type" : "Valitse tyyppi",
    "Select Date" : "Valitse päivä",
    "Add contact in group" : "Lisää yhteystieto ryhmään",
    "No results" : "Ei tuloksia",
    "Last modified" : "Viimeksi muokattu",
    "Select option" : "Valitse valinta",
    "Rename" : "Nimeä uudelleen",
    "Enabled" : "Käytössä",
    "Disabled" : "Pois käytöstä",
    "Copied" : "Kopioitu",
    "Can not copy" : "Ei voida kopioida",
    "Copy link" : "Kopioi linkki",
    "This will delete the addressbook and every contacts within it" : "Tämä poistaa osoitekirjan ja kaikki siinä olevat yhteystiedot",
    "Delete {addressbook} ?" : "Poistetaanko {addressbook} ?",
    "Deletion of addressbook was not successful." : "Osoitekirjan poistaminen ei onnistunut.",
    "Renaming of addressbook was not successful." : "Osoitekirja nimen muuttaminen ei onnistunut.",
    "Addressbook copied to clipboard" : "Osoitekirja kopioitu leikepöydälle",
    "Addressbook was not copied to clipboard." : "Osoitekirjaa ei kopioitu leikepöydälle.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Jaettu {num} entiteetin kanssa","Jaettu {num} entiteetin kanssa"],
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "can edit" : "voi muokata",
    "Unable to delete the share." : "Jakoa ei voitu poistaa.",
    "Unable to change permissions." : "Käyttöoikeuksia ei voitu muuttaa.",
    "Import into" : "Tuo kirjaan",
    "Importing is disabled because there are no address books available" : "Tuonti on pois käytöstä, koska osoitekirjoja ei ole käytettävissä",
    "Address book name" : "Osoitekirjan nimi",
    "An error occurred, unable to create the addressbook." : "Tapahtui virhe, osoitekirjaa ei voitu luoda.",
    "First name" : "Etunimi",
    "Last name" : "Sukunimi",
    "Display name" : "Näyttönimi",
    "Sort by {sorting}" : "Järjestysperuste {sorting}",
    "Not grouped" : "Ei ryhmitelty",
    "Unable to create the contact." : "Yhteystiedon luominen ei onnistunut.",
    "Contact not found" : "Yhteytietoa ei löytynyt",
    "Nickname" : "Kutsumanimi",
    "Detailed name" : "Täsmällinen nimi",
    "Additional names" : "Lisänimet",
    "Prefix" : "Etuliite",
    "Suffix" : "Takaliite",
    "Copy to full name" : "Kopioi koko nimeksi",
    "Notes" : "Huomiot",
    "Website" : "Verkkosivusto",
    "Federated Cloud ID" : "Federoidun pilven tunniste",
    "Home" : "Koti",
    "Work" : "Työ",
    "Other" : "Muu",
    "Address" : "Osoite",
    "Post office box" : "Postilokero",
    "Extended address" : "Laajennettu osoite",
    "City" : "Paikkakunta",
    "State or province" : "Maakunta tai osavaltio",
    "Postal code" : "Postinumero",
    "Country" : "Maa",
    "Birthday" : "Syntymäpäivä",
    "Anniversary" : "Vuosipäivä",
    "Date of death" : "Kuolinpäivä",
    "Email" : "Sähköpostiosoite",
    "Instant messaging" : "Pikaviestintä",
    "Phone" : "Puhelin",
    "Mobile" : "Mobiili",
    "Work mobile" : "Työmatkapuhelin",
    "Home mobile" : "Kotimatkapuhelin",
    "Fax" : "Faksi",
    "Fax home" : "Faksi, koti",
    "Fax work" : "Faksi, työ",
    "Pager" : "Hakulaite",
    "Voice" : "Ääni",
    "Car" : "Auto",
    "Work pager" : "Työhakulaite",
    "Social network" : "Sosiaalinen verkosto",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Profiilin osoite, esim. https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Ihmissuhde",
    "Spouse" : "Puoliso",
    "Child" : "Lapsi",
    "Mother" : "Äiti",
    "Father" : "Isä",
    "Parent" : "Vanhempi",
    "Brother" : "Veli",
    "Sister" : "Sisko",
    "Relative" : "Sukulainen",
    "Friend" : "Kaveri",
    "Colleague" : "Työkaveri",
    "Manager" : "Esimies",
    "Assistant" : "Avustaja",
    "Emergency" : "Hätä",
    "Co-worker" : "Työkaveri",
    "Gender" : "Sukupuoli",
    "Female" : "Nainen",
    "Male" : "Mies",
    "Unknown" : "Tuntematon",
    "An error occurred" : "Tapahtui virhe",
    "Your web browser is out of date" : "Käyttämäsi selain on vanhentunut",
    "This application is not compatible with Internet Explorer" : "Tämä sovellus ei ole yhteensopiva Internet Explorerin kanssa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-3.1.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/fi.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Yhteystiedot",
    "All contacts" : "Kaikki yhteystiedot",
    "Details" : "Tiedot",
    "A contacts app for Nextcloud" : "Yhteystietosovellus Nextcloudille",
    "Copy to full name" : "Kopioi koko nimeksi",
    "Add new property" : "Lisää uusi ominaisuus",
    "Choose property type" : "Valitse ominaisuuden tyyppi",
    "Add a new picture" : "Lisää uusi kuva",
    "Upload a new picture" : "Lähetä uusi kuva",
    "Choose from files" : "Valitse tiedostoista",
    "Delete picture" : "Poista kuva",
    "Download picture" : "Lataa kuva",
    "Image is too big (max 1MB)." : "Kuva on liian suuri (enintään 1 Mt).",
    "Pick an avatar" : "Valitse avatar",
    "Error while processing the picture." : "Virhe kuvan käsittelyn aikana.",
    "No contact selected" : "Yhteystietoa ei ole valittu",
    "Select a contact on the list to begin" : "Valitse yhteystieto luettelosta aloittaaksesi",
    "Loading" : "Ladataan",
    "Name" : "Nimi",
    "Company" : "Yritys",
    "Title" : "Nimeke",
    "Download" : "Lataa",
    "Generate QR Code" : "Luo QR-koodi",
    "Delete" : "Poista",
    "This contact is not yet synced. Edit it to save it to the server." : "Tätä yhteystietoa ei ole vielä synkronoitu. Muokkaa yhteystietoa tallentaaksesi sen palvelimelle.",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tämä yhteystieto on \"vain luku\"-tilassa. Sinulla ei ole oikeuksia muokata tätä yhteystietoa.",
    "Addressbook" : "Osoitekirja",
    "Groups" : "Ryhmät",
    "New contact" : "Uusi yhteystieto",
    "Deleting the contact in {countdown} seconds" : "Poistetaan yhteystieto {countdown} sekunnin kuluttua",
    "No errors" : "Ei virheitä",
    "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} virheellinen yhteystieto","{failedCount} virheellistä yhteystietoa"],
    "Select type" : "Valitse tyyppi",
    "Select Date" : "Valitse päivä",
    "Add contact in group" : "Lisää yhteystieto ryhmään",
    "No results" : "Ei tuloksia",
    "Last modified" : "Viimeksi muokattu",
    "Select option" : "Valitse valinta",
    "Rename" : "Nimeä uudelleen",
    "Enabled" : "Käytössä",
    "Disabled" : "Pois käytöstä",
    "Copied" : "Kopioitu",
    "Can not copy" : "Ei voida kopioida",
    "Copy link" : "Kopioi linkki",
    "This will delete the addressbook and every contacts within it" : "Tämä poistaa osoitekirjan ja kaikki siinä olevat yhteystiedot",
    "Delete {addressbook} ?" : "Poistetaanko {addressbook} ?",
    "Deletion of addressbook was not successful." : "Osoitekirjan poistaminen ei onnistunut.",
    "Renaming of addressbook was not successful." : "Osoitekirja nimen muuttaminen ei onnistunut.",
    "Addressbook copied to clipboard" : "Osoitekirja kopioitu leikepöydälle",
    "Addressbook was not copied to clipboard." : "Osoitekirjaa ei kopioitu leikepöydälle.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Jaettu {num} entiteetin kanssa","Jaettu {num} entiteetin kanssa"],
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "can edit" : "voi muokata",
    "Unable to delete the share." : "Jakoa ei voitu poistaa.",
    "Unable to change permissions." : "Käyttöoikeuksia ei voitu muuttaa.",
    "Import into" : "Tuo kirjaan",
    "Importing is disabled because there are no address books available" : "Tuonti on pois käytöstä, koska osoitekirjoja ei ole käytettävissä",
    "Address book name" : "Osoitekirjan nimi",
    "An error occurred, unable to create the addressbook." : "Tapahtui virhe, osoitekirjaa ei voitu luoda.",
    "First name" : "Etunimi",
    "Last name" : "Sukunimi",
    "Display name" : "Näyttönimi",
    "Sort by {sorting}" : "Järjestysperuste {sorting}",
    "Not grouped" : "Ei ryhmitelty",
    "Unable to create the contact." : "Yhteystiedon luominen ei onnistunut.",
    "Contact not found" : "Yhteytietoa ei löytynyt",
    "Nickname" : "Kutsumanimi",
    "Detailed name" : "Täsmällinen nimi",
    "Additional names" : "Lisänimet",
    "Prefix" : "Etuliite",
    "Suffix" : "Takaliite",
    "Notes" : "Huomiot",
    "Website" : "Verkkosivusto",
    "Federated Cloud ID" : "Federoidun pilven tunniste",
    "Home" : "Koti",
    "Work" : "Työ",
    "Other" : "Muu",
    "Address" : "Osoite",
    "Post office box" : "Postilokero",
    "Extended address" : "Laajennettu osoite",
    "City" : "Paikkakunta",
    "State or province" : "Maakunta tai osavaltio",
    "Postal code" : "Postinumero",
    "Country" : "Maa",
    "Birthday" : "Syntymäpäivä",
    "Anniversary" : "Vuosipäivä",
    "Date of death" : "Kuolinpäivä",
    "Email" : "Sähköpostiosoite",
    "Instant messaging" : "Pikaviestintä",
    "Phone" : "Puhelin",
    "Mobile" : "Mobiili",
    "Work mobile" : "Työmatkapuhelin",
    "Home mobile" : "Kotimatkapuhelin",
    "Fax" : "Faksi",
    "Fax home" : "Faksi, koti",
    "Fax work" : "Faksi, työ",
    "Pager" : "Hakulaite",
    "Voice" : "Ääni",
    "Car" : "Auto",
    "Work pager" : "Työhakulaite",
    "Social network" : "Sosiaalinen verkosto",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Profiilin osoite, esim. https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Ihmissuhde",
    "Spouse" : "Puoliso",
    "Child" : "Lapsi",
    "Mother" : "Äiti",
    "Father" : "Isä",
    "Parent" : "Vanhempi",
    "Brother" : "Veli",
    "Sister" : "Sisko",
    "Relative" : "Sukulainen",
    "Friend" : "Kaveri",
    "Colleague" : "Työkaveri",
    "Manager" : "Esimies",
    "Assistant" : "Avustaja",
    "Emergency" : "Hätä",
    "Co-worker" : "Työkaveri",
    "Gender" : "Sukupuoli",
    "Female" : "Nainen",
    "Male" : "Mies",
    "Unknown" : "Tuntematon",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} yhteystietoa ei voitu lukea","{failed} yhteystietoa ei voitu lukea"],
    "An error occurred" : "Tapahtui virhe",
    "Your web browser is out of date" : "Käyttämäsi selain on vanhentunut",
    "This application is not compatible with Internet Explorer" : "Tämä sovellus ei ole yhteensopiva Internet Explorerin kanssa"
},
"nplurals=2; plural=(n != 1);");
